build: fix circular header inclusion with other packages
authorYang Tse <yangsita@gmail.com>
Sun, 6 Jan 2013 18:06:49 +0000 (19:06 +0100)
committerYang Tse <yangsita@gmail.com>
Tue, 8 Jan 2013 23:49:50 +0000 (00:49 +0100)
This commit renames lib/setup.h to lib/curl_setup.h and
renames lib/setup_once.h to lib/curl_setup_once.h.

Removes the need and usage of a header inclusion guard foreign
to libcurl. [1]

Removes the need and presence of an alarming notice we carried
in old setup_once.h [2]

----------------------------------------

1 - lib/setup_once.h used __SETUP_ONCE_H macro as header inclusion guard
    up to commit ec691ca3 which changed this to HEADER_CURL_SETUP_ONCE_H,
    this single inclusion guard is enough to ensure that inclusion of
    lib/setup_once.h done from lib/setup.h is only done once.

    Additionally lib/setup.h has always used __SETUP_ONCE_H macro to
    protect inclusion of setup_once.h even after commit ec691ca3, this
    was to avoid a circular header inclusion triggered when building a
    c-ares enabled version with c-ares sources available which also has
    a setup_once.h header. Commit ec691ca3 exposes the real nature of
    __SETUP_ONCE_H usage in lib/setup.h, it is a header inclusion guard
    foreign to libcurl belonging to c-ares's setup_once.h

    The renaming this commit does, fixes the circular header inclusion,
    and as such removes the need and usage of a header inclusion guard
    foreign to libcurl. Macro __SETUP_ONCE_H no longer used in libcurl.

2 - Due to the circular interdependency of old lib/setup_once.h and the
    c-ares setup_once.h header, old file lib/setup_once.h has carried
    back from 2006 up to now days an alarming and prominent notice about
    the need of keeping libcurl's and c-ares's setup_once.h in sync.

    Given that this commit fixes the circular interdependency, the need
    and presence of mentioned notice is removed.

    All mentioned interdependencies come back from now old days when
    the c-ares project lived inside a curl subdirectory. This commit
    removes last traces of such fact.

183 files changed:
docs/INSTALL
docs/examples/Makefile.am
include/curl/curlrules.h
lib/Makefile.am
lib/Makefile.inc
lib/README.hostip
lib/amigaos.c
lib/amigaos.h
lib/asyn-ares.c
lib/asyn-thread.c
lib/asyn.h
lib/axtls.c
lib/base64.c
lib/bundles.c
lib/conncache.c
lib/connect.c
lib/connect.h
lib/content_encoding.c
lib/content_encoding.h
lib/cookie.c
lib/cookie.h
lib/curl_addrinfo.c
lib/curl_addrinfo.h
lib/curl_darwinssl.c
lib/curl_darwinssl.h
lib/curl_fnmatch.c
lib/curl_gethostname.c
lib/curl_gssapi.c
lib/curl_gssapi.h
lib/curl_md4.h
lib/curl_memrchr.c
lib/curl_memrchr.h
lib/curl_multibyte.c
lib/curl_multibyte.h
lib/curl_ntlm.c
lib/curl_ntlm.h
lib/curl_ntlm_core.c
lib/curl_ntlm_core.h
lib/curl_ntlm_msgs.c
lib/curl_ntlm_msgs.h
lib/curl_ntlm_wb.c
lib/curl_ntlm_wb.h
lib/curl_rand.c
lib/curl_rtmp.c
lib/curl_sasl.c
lib/curl_schannel.c
lib/curl_schannel.h
lib/curl_setup.h [moved from lib/setup.h with 99% similarity]
lib/curl_setup_once.h [moved from lib/setup_once.h with 96% similarity]
lib/curl_sspi.c
lib/curl_sspi.h
lib/curl_threads.c
lib/curl_threads.h
lib/cyassl.c
lib/cyassl.h
lib/dict.c
lib/easy.c
lib/escape.c
lib/file.c
lib/fileinfo.c
lib/formdata.c
lib/ftp.c
lib/ftplistparser.c
lib/ftplistparser.h
lib/getenv.c
lib/getinfo.c
lib/gopher.c
lib/gtls.c
lib/gtls.h
lib/hash.c
lib/hash.h
lib/hmac.c
lib/hostasyn.c
lib/hostcheck.c
lib/hostip.c
lib/hostip.h
lib/hostip4.c
lib/hostip6.c
lib/hostsyn.c
lib/http.c
lib/http_chunks.c
lib/http_digest.c
lib/http_digest.h
lib/http_negotiate.c
lib/http_negotiate_sspi.c
lib/http_proxy.c
lib/idn_win32.c
lib/if2ip.c
lib/if2ip.h
lib/imap.c
lib/inet_ntop.c
lib/inet_ntop.h
lib/inet_pton.c
lib/inet_pton.h
lib/krb4.c
lib/krb5.c
lib/ldap.c
lib/llist.c
lib/llist.h
lib/md4.c
lib/md5.c
lib/memdebug.c
lib/memdebug.h
lib/mprintf.c
lib/multi.c
lib/netrc.c
lib/non-ascii.c
lib/non-ascii.h
lib/nonblock.c
lib/nss.c
lib/nssg.h
lib/nwlib.c
lib/nwos.c
lib/openldap.c
lib/parsedate.c
lib/pingpong.c
lib/pingpong.h
lib/polarssl.c
lib/polarssl.h
lib/pop3.c
lib/progress.c
lib/qssl.c
lib/qssl.h
lib/rawstr.c
lib/rtsp.c
lib/security.c
lib/select.c
lib/select.h
lib/sendf.c
lib/sendf.h
lib/share.c
lib/share.h
lib/slist.c
lib/smtp.c
lib/sockaddr.h
lib/socks.c
lib/socks.h
lib/socks_gssapi.c
lib/socks_sspi.c
lib/speedcheck.c
lib/speedcheck.h
lib/splay.c
lib/splay.h
lib/ssh.c
lib/ssh.h
lib/sslgen.c
lib/sslgen.h
lib/ssluse.c
lib/ssluse.h
lib/strdup.c
lib/strdup.h
lib/strequal.c
lib/strerror.c
lib/strtok.c
lib/strtok.h
lib/strtoofft.c
lib/strtoofft.h
lib/telnet.c
lib/tftp.c
lib/timeval.h
lib/transfer.c
lib/url.c
lib/url.h
lib/urldata.h
lib/version.c
lib/warnless.c
lib/wildcard.c
m4/curl-reentrant.m4
packages/OS400/os400sys.c
src/CMakeLists.txt
src/Makefile.am
src/tool_setup.h
tests/libtest/CMakeLists.txt
tests/libtest/Makefile.am
tests/libtest/chkhostname.c
tests/libtest/sethostname.c
tests/libtest/test.h
tests/libtest/testutil.c
tests/libtest/testutil.h
tests/server/CMakeLists.txt
tests/server/Makefile.am
tests/server/server_setup.h
tests/unit/Makefile.am

index 0ed15ca..a39f19c 100644 (file)
@@ -464,7 +464,7 @@ Win32
    possibilities:
 
    - Modify lib/config-win32.h
-   - Modify lib/setup.h
+   - Modify lib/curl_setup.h
    - Modify lib/Makefile.vc6
    - Add defines to Project/Settings/C/C++/General/Preprocessor Definitions
      in the vc6libcurl.dsw/vc6libcurl.dsp Visual C++ 6 IDE project.
index 865f093..cbfdac5 100644 (file)
@@ -31,7 +31,7 @@ EXTRA_DIST = README Makefile.example Makefile.inc Makefile.m32 \
 # might possibly already be installed in the system.
 #
 # $(top_builddir)/include/curl for generated curlbuild.h included from curl.h
-# $(top_builddir)/include for generated curlbuild.h included from lib/setup.h
+# $(top_builddir)/include for generated curlbuild.h inc. from lib/curl_setup.h
 # $(top_srcdir)/include is for libcurl's external include files
 
 AM_CPPFLAGS = -I$(top_builddir)/include/curl \
index 4e9c880..7c2ede3 100644 (file)
@@ -190,7 +190,7 @@ typedef char
  * CURL_ISOCPP and CURL_OFF_T_C definitions are done here in order to allow
  * these to be visible and exported by the external libcurl interface API,
  * while also making them visible to the library internals, simply including
- * setup.h, without actually needing to include curl.h internally.
+ * curl_setup.h, without actually needing to include curl.h internally.
  * If some day this section would grow big enough, all this should be moved
  * to its own header file.
  */
index bb7721d..3eb4977 100644 (file)
@@ -57,10 +57,10 @@ CFLAG_CURL_SYMBOL_HIDING = @CFLAG_CURL_SYMBOL_HIDING@
 # might possibly already be installed in the system.
 #
 # $(top_builddir)/include/curl for generated curlbuild.h included from curl.h
-# $(top_builddir)/include for generated curlbuild.h included from lib/setup.h
+# $(top_builddir)/include for generated curlbuild.h inc. from lib/curl_setup.h
 # $(top_srcdir)/include is for libcurl's external include files
 # $(top_builddir)/lib is for libcurl's generated lib/curl_config.h file
-# $(top_srcdir)/lib is for libcurl's lib/setup.h and other "private" files
+# $(top_srcdir)/lib for libcurl's lib/curl_setup.h and other "private" files
 # $(top_builddir)/ares is for in-tree c-ares's generated ares_build.h file
 # $(top_srcdir)/ares is for in-tree c-ares's external include files
 
index f97ef6d..b116b39 100644 (file)
@@ -34,13 +34,13 @@ HHEADERS = arpa_telnet.h netrc.h file.h timeval.h qssl.h hostip.h   \
   curl_fnmatch.h wildcard.h fileinfo.h ftplistparser.h strtok.h                \
   connect.h llist.h hash.h content_encoding.h share.h curl_md4.h       \
   curl_md5.h http_digest.h http_negotiate.h inet_pton.h amigaos.h      \
-  strtoofft.h strerror.h inet_ntop.h curlx.h curl_memory.h setup.h     \
+  strtoofft.h strerror.h inet_ntop.h curlx.h curl_memory.h curl_setup.h        \
   transfer.h select.h easyif.h multiif.h parsedate.h sslgen.h gtls.h   \
-  tftp.h sockaddr.h splay.h strdup.h setup_once.h socks.h ssh.h nssg.h \
+  tftp.h sockaddr.h splay.h strdup.h socks.h ssh.h nssg.h              \
   curl_base64.h rawstr.h curl_addrinfo.h curl_sspi.h slist.h nonblock.h        \
   curl_memrchr.h imap.h pop3.h smtp.h pingpong.h rtsp.h curl_threads.h \
   warnless.h curl_hmac.h polarssl.h curl_rtmp.h curl_gethostname.h     \
   gopher.h axtls.h cyassl.h http_proxy.h non-ascii.h asyn.h curl_ntlm.h        \
   curl_gssapi.h curl_ntlm_wb.h curl_ntlm_core.h curl_ntlm_msgs.h       \
   curl_sasl.h curl_schannel.h curl_multibyte.h curl_darwinssl.h        \
-  hostcheck.h bundles.h conncache.h
+  hostcheck.h bundles.h conncache.h curl_setup_once.h
index 9723b93..2e30bc7 100644 (file)
@@ -32,4 +32,4 @@
  hostip6.c  - ipv6-specific functions
 
  The hostip.h is the single united header file for all this. It defines the
- CURLRES_* defines based on the config*.h and setup.h defines.
+ CURLRES_* defines based on the config*.h and curl_setup.h defines.
index 71ea704..34f95e9 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #if defined(__AMIGA__) && !defined(__ixemul__)
 
index 7476a13..76578be 100644 (file)
@@ -21,7 +21,7 @@
  * KIND, either express or implied.
  *
  ***************************************************************************/
-#include "setup.h"
+#include "curl_setup.h"
 
 #if defined(__AMIGA__) && !defined(__ixemul__)
 
index 44d00bd..fdfa2a3 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef HAVE_LIMITS_H
 #include <limits.h>
index 0d29d58..7a8294d 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef HAVE_NETINET_IN_H
 #include <netinet/in.h>
index e7c1b88..1b681ea 100644 (file)
@@ -22,7 +22,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 #include "curl_addrinfo.h"
 
 struct addrinfo;
index 19ed730..d512950 100644 (file)
@@ -26,7 +26,7 @@
  * but sslgen.c should ever call or use these functions.
  */
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef USE_AXTLS
 #include <axTLS/ssl.h>
index ec46c09..3f3f0f9 100644 (file)
@@ -22,7 +22,7 @@
 
 /* Base64 encoding/decoding */
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #define _MPRINTF_REPLACE /* use our functions only */
 #include <curl/mprintf.h>
index f09ee2a..aadf026 100644 (file)
@@ -21,7 +21,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #include <curl/curl.h>
 
index a3a90f8..165a26f 100644 (file)
@@ -21,7 +21,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #include <curl/curl.h>
 
index 19f5b2f..acaf3b4 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef HAVE_NETINET_IN_H
 #include <netinet/in.h> /* <netinet/tcp.h> may need it */
index f84361f..ab98002 100644 (file)
@@ -21,7 +21,7 @@
  * KIND, either express or implied.
  *
  ***************************************************************************/
-#include "setup.h"
+#include "curl_setup.h"
 
 #include "nonblock.h" /* for curlx_nonblock(), formerly Curl_nonblock() */
 #include "sockaddr.h"
index 3276ef9..c68e6e5 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef HAVE_LIBZ
 
index 372da4a..501f6c8 100644 (file)
@@ -21,7 +21,7 @@
  * KIND, either express or implied.
  *
  ***************************************************************************/
-#include "setup.h"
+#include "curl_setup.h"
 
 /*
  * Comma-separated list all supported Content-Encodings ('identity' is implied)
index 644b33a..18b9155 100644 (file)
@@ -77,7 +77,7 @@ Example set of cookies:
 ****/
 
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #if !defined(CURL_DISABLE_HTTP) && !defined(CURL_DISABLE_COOKIES)
 
index 5997e46..d3b63f7 100644 (file)
@@ -21,7 +21,7 @@
  * KIND, either express or implied.
  *
  ***************************************************************************/
-#include "setup.h"
+#include "curl_setup.h"
 
 #include <curl/curl.h>
 
index 815b4ae..10652c6 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #include <curl/curl.h>
 
index a5375cb..6d2b753 100644 (file)
@@ -22,7 +22,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef HAVE_NETINET_IN_H
 #  include <netinet/in.h>
index 2d56b39..e8fa275 100644 (file)
@@ -26,7 +26,7 @@
  * TLS/SSL layer. No code but sslgen.c should ever call or use these functions.
  */
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef USE_DARWINSSL
 
index 53053ed..183d937 100644 (file)
@@ -21,7 +21,7 @@
  * KIND, either express or implied.
  *
  ***************************************************************************/
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef USE_DARWINSSL
 
index e18f52e..63f67b9 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #include "curl_fnmatch.h"
 
index ddee4ba..ded1e6f 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #include "curl_gethostname.h"
 
index b9c8ad0..fabbe35 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef HAVE_GSSAPI
 
index fd4596b..ed33b51 100644 (file)
@@ -22,7 +22,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 #include "urldata.h"
 
 #ifdef HAVE_GSSAPI
index 6b6c16e..b0be9cf 100644 (file)
@@ -22,7 +22,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 /* NSS crypto library does not provide the MD4 hash algorithm, so that we have
  * a local implementation of it */
index d79af9b..a71c2bb 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #include "curl_memrchr.h"
 
index 37061b6..324c73a 100644 (file)
@@ -22,7 +22,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef HAVE_MEMRCHR
 
index 7cb9e4c..6c02239 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #if defined(USE_WIN32_IDN) || (defined(USE_WINDOWS_SSPI) && defined(UNICODE))
 
index 6ecccd3..7ee5eae 100644 (file)
@@ -21,7 +21,7 @@
  * KIND, either express or implied.
  *
  ***************************************************************************/
-#include "setup.h"
+#include "curl_setup.h"
 
 #if defined(USE_WIN32_IDN) || (defined(USE_WINDOWS_SSPI) && defined(UNICODE))
 
index 9c78372..72e446c 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef USE_NTLM
 
index b278377..21a9e9e 100644 (file)
@@ -22,7 +22,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef USE_NTLM
 
index 6b7d9fc..8f3c00d 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #if defined(USE_NTLM) && !defined(USE_WINDOWS_SSPI)
 
index 5615b35..9aa126b 100644 (file)
@@ -22,7 +22,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #if defined(USE_NTLM) && !defined(USE_WINDOWS_SSPI)
 
index 8e788d7..93334c6 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef USE_NTLM
 
index 703fb75..e7d185d 100644 (file)
@@ -22,7 +22,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef USE_NTLM
 
index 46a51c2..b1c20e1 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #if defined(USE_NTLM) && defined(NTLM_WB_ENABLED)
 
index e3eaffe..db6bc16 100644 (file)
@@ -22,7 +22,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #if defined(USE_NTLM) && defined(NTLM_WB_ENABLED)
 
index 047b7f3..dc49289 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #include <curl/curl.h>
 
index b87bdf2..45da35c 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef USE_LIBRTMP
 
index 8062e53..7f99830 100644 (file)
@@ -25,7 +25,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #include <curl/curl.h>
 #include "urldata.h"
index 8cb3af8..b71d8d4 100644 (file)
@@ -51,7 +51,7 @@
  *   http://msdn.microsoft.com/en-us/library/windows/desktop/aa380161.aspx
  */
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef USE_SCHANNEL
 
index 37126ac..b82c734 100644 (file)
@@ -22,7 +22,7 @@
  * KIND, either express or implied.
  *
  ***************************************************************************/
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef USE_SCHANNEL
 
similarity index 99%
rename from lib/setup.h
rename to lib/curl_setup.h
index 6d2dc90..37be5ae 100644 (file)
@@ -645,9 +645,7 @@ int netware_init(void);
  * Include macros and defines that should only be processed once.
  */
 
-#ifndef __SETUP_ONCE_H
-#include "setup_once.h"
-#endif
+#include "curl_setup_once.h"
 
 /*
  * Definition of our NOP statement Object-like macro
similarity index 96%
rename from lib/setup_once.h
rename to lib/curl_setup_once.h
index 2d55c40..57d3ea9 100644 (file)
  ***************************************************************************/
 
 
-/********************************************************************
- *                              NOTICE                              *
- *                             ========                             *
- *                                                                  *
- *  Content of header files lib/setup_once.h and ares/setup_once.h  *
- *  must be kept in sync. Modify the other one if you change this.  *
- *                                                                  *
- ********************************************************************/
-
-
 /*
  * Inclusion of common header files.
  */
index c3c41ec..e747d86 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef USE_WINDOWS_SSPI
 
index c3e6d97..d525828 100644 (file)
@@ -22,7 +22,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef USE_WINDOWS_SSPI
 
index 411ccc8..c9e91f6 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #if defined(USE_THREADS_POSIX)
 #  ifdef HAVE_PTHREAD_H
index ba81054..d9cec6b 100644 (file)
@@ -21,7 +21,7 @@
  * KIND, either express or implied.
  *
  ***************************************************************************/
-#include "setup.h"
+#include "curl_setup.h"
 
 #if defined(USE_THREADS_POSIX)
 #  define CURL_STDCALL
index 13c0d13..7c78464 100644 (file)
@@ -26,7 +26,7 @@
  *
  */
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef USE_CYASSL
 
index 56d6806..7728a0c 100644 (file)
@@ -21,7 +21,7 @@
  * KIND, either express or implied.
  *
  ***************************************************************************/
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef USE_CYASSL
 
index ca5c362..f5c8921 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifndef CURL_DISABLE_DICT
 
index b73bf66..700fb32 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef HAVE_NETINET_IN_H
 #include <netinet/in.h>
index 0dd5a1d..6a26cf8 100644 (file)
@@ -23,7 +23,7 @@
 /* Escape and unescape URL encoding in strings. The functions return a new
  * allocated string or NULL if an error occurred.  */
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #include <curl/curl.h>
 
index 886a09e..038bf42 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifndef CURL_DISABLE_FILE
 
index 4ffcbbe..8c8ee98 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #include "strdup.h"
 #include "fileinfo.h"
index 7bf8839..6d78b79 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #include <curl/curl.h>
 
index dc24d0b..29b9743 100644 (file)
--- a/lib/ftp.c
+++ b/lib/ftp.c
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifndef CURL_DISABLE_FTP
 
index 49ee4b6..cb3601f 100644 (file)
@@ -35,7 +35,7 @@
  * 01-29-97 11:32PM <DIR> prog
  */
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifndef CURL_DISABLE_FTP
 
index 8499ccd..96764e2 100644 (file)
@@ -21,7 +21,7 @@
  * KIND, either express or implied.
  *
  ***************************************************************************/
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifndef CURL_DISABLE_FTP
 
index a2d6983..19da29a 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef __VMS
 #include <unixlib.h>
index 221f05a..74e5b08 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #include <curl/curl.h>
 
index e8f2790..b1dd65f 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifndef CURL_DISABLE_GOPHER
 
index 8c2a4a0..700e46a 100644 (file)
@@ -28,7 +28,7 @@
  * since they were not present in 1.0.X.
  */
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef USE_GNUTLS
 
@@ -94,7 +94,8 @@ static bool gtls_inited = FALSE;
 /*
  * Custom push and pull callback functions used by GNU TLS to read and write
  * to the socket.  These functions are simple wrappers to send() and recv()
- * (although here using the sread/swrite macros as defined by setup_once.h).
+ * (although here using the sread/swrite macros as defined by
+ * curl_setup_once.h).
  * We use custom functions rather than the GNU TLS defaults because it allows
  * us to get specific about the fourth "flags" argument, and to use arbitrary
  * private data with gnutls_transport_set_ptr if we wish.
index 45b755a..84e1396 100644 (file)
@@ -22,7 +22,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef USE_GNUTLS
 
index b59e561..0a8e99a 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #include "hash.h"
 #include "llist.h"
index 3fa621c..99a6274 100644 (file)
@@ -22,7 +22,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #include <stddef.h>
 
index 4df6f79..dace820 100644 (file)
@@ -22,7 +22,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifndef CURL_DISABLE_CRYPTO_AUTH
 
index 93e2c31..8151b67 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef HAVE_NETINET_IN_H
 #include <netinet/in.h>
index 8affce0..44ad822 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #if defined(USE_SSLEAY) || defined(USE_AXTLS)
 /* these two backends use functions from this file */
index 2bfb74b..3765ca1 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef HAVE_NETINET_IN_H
 #include <netinet/in.h>
  * asyn-thread.c - functions for threaded name resolves
 
  * The hostip.h is the united header file for all this. It defines the
- * CURLRES_* defines based on the config*.h and setup.h defines.
+ * CURLRES_* defines based on the config*.h and curl_setup.h defines.
  */
 
 /* These two symbols are for the global DNS cache */
index de71f54..9dd47ba 100644 (file)
@@ -22,7 +22,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 #include "hash.h"
 #include "curl_addrinfo.h"
 #include "asyn.h"
index 3babe72..3a38b32 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef HAVE_NETINET_IN_H
 #include <netinet/in.h>
index 5b25d6f..c42760a 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef HAVE_NETINET_IN_H
 #include <netinet/in.h>
index eff2efa..65a4035 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef HAVE_NETINET_IN_H
 #include <netinet/in.h>
index 0013e50..21f7c21 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifndef CURL_DISABLE_HTTP
 
index d6a0bec..e9fddf5 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifndef CURL_DISABLE_HTTP
 
index 17cc95e..f9f20d4 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #if !defined(CURL_DISABLE_HTTP) && !defined(CURL_DISABLE_CRYPTO_AUTH)
 
index 3b22ce1..c6a4e91 100644 (file)
@@ -21,7 +21,7 @@
  * KIND, either express or implied.
  *
  ***************************************************************************/
-#include "setup.h"
+#include "curl_setup.h"
 
 typedef enum {
   CURLDIGEST_NONE, /* not a digest */
index 92c363d..535a427 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef HAVE_GSSAPI
 #ifdef HAVE_OLD_GSSMIT
index 5aa4f94..1381d52 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef USE_WINDOWS_SSPI
 
index d2e1aa1..ada8957 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #if !defined(CURL_DISABLE_PROXY) && !defined(CURL_DISABLE_HTTP)
 
index 9bc9cb8..464964b 100644 (file)
@@ -24,7 +24,7 @@
   * IDN conversions using Windows kernel32 and normaliz libraries.
   */
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef USE_WIN32_IDN
 
index c1905d1..558e30f 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef HAVE_NETINET_IN_H
 #  include <netinet/in.h>
index 7084245..858ec2f 100644 (file)
@@ -21,7 +21,7 @@
  * KIND, either express or implied.
  *
  ***************************************************************************/
-#include "setup.h"
+#include "curl_setup.h"
 
 bool Curl_if_is_interface_name(const char *interf);
 char *Curl_if2ip(int af, const char *interf, char *buf, int buf_size);
index 0fa1acc..a53f2e9 100644 (file)
@@ -28,7 +28,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifndef CURL_DISABLE_IMAP
 
index 1ff9756..c327150 100644 (file)
@@ -18,7 +18,7 @@
  * Original code by Paul Vixie. "curlified" by Gisle Vanem.
  */
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifndef HAVE_INET_NTOP
 
index dbc146d..db28ed8 100644 (file)
@@ -22,7 +22,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 char *Curl_inet_ntop(int af, const void *addr, char *buf, size_t size);
 
index d7fbbe9..f50b365 100644 (file)
@@ -16,7 +16,7 @@
  * SOFTWARE.
  */
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifndef HAVE_INET_PTON
 
index f991473..43c5491 100644 (file)
@@ -22,7 +22,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 int Curl_inet_pton(int, const char *, void *);
 
index 58354b6..3d78962 100644 (file)
@@ -39,7 +39,7 @@
  *
  */
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifndef CURL_DISABLE_FTP
 #ifdef HAVE_KRB4
index c51041d..1e99c70 100644 (file)
@@ -32,7 +32,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.  */
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifndef CURL_DISABLE_FTP
 #ifdef HAVE_GSSAPI
index 9ef3100..833ffa4 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #if !defined(CURL_DISABLE_LDAP) && !defined(USE_OPENLDAP)
 
index a302e32..40bb628 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #include "llist.h"
 #include "curl_memory.h"
index b4ca82a..27ddb71 100644 (file)
@@ -22,7 +22,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 #include <stddef.h>
 
 typedef void (*curl_llist_dtor)(void *, void *);
index cf6c360..6930e02 100644 (file)
--- a/lib/md4.c
+++ b/lib/md4.c
@@ -20,7 +20,7 @@
    documentation and/or software.
  */
 
-#include "setup.h"
+#include "curl_setup.h"
 
 /* NSS crypto library does not provide the MD4 hash algorithm, so that we have
  * a local implementation of it */
index ae5812b..57efa43 100644 (file)
--- a/lib/md5.c
+++ b/lib/md5.c
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifndef CURL_DISABLE_CRYPTO_AUTH
 
index c95f41f..4d5f44d 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef CURLDEBUG
 
index 1716e35..fbeb61d 100644 (file)
@@ -28,7 +28,7 @@
  * as well as the library. Do not mix with library internals!
  */
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #include <curl/curl.h>
 
index 0990f40..b5b8153 100644 (file)
@@ -35,7 +35,7 @@
  * page at http://daniel.haxx.se/trio/
  */
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #if defined(DJGPP) && (DJGPP_MINOR < 4)
 #undef _MPRINTF_REPLACE /* don't use x_was_used() here */
index dae1f6b..de1fc7d 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #include <curl/curl.h>
 
index 162a86c..1b834b8 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef HAVE_PWD_H
 #include <pwd.h>
index 8e29227..91d6a54 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef CURL_DOES_CONVERSIONS
 
index 6dcbe00..8b4b7c2 100644 (file)
@@ -21,7 +21,7 @@
  * KIND, either express or implied.
  *
  ***************************************************************************/
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef CURL_DOES_CONVERSIONS
 
index a2722ed..1447c87 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef HAVE_SYS_IOCTL_H
 #include <sys/ioctl.h>
index 86ce6a6..298ddad 100644 (file)
--- a/lib/nss.c
+++ b/lib/nss.c
@@ -25,7 +25,7 @@
  * but sslgen.c should ever call or use these functions.
  */
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef USE_NSS
 
index 647b7bb..a881a9a 100644 (file)
@@ -21,7 +21,7 @@
  * KIND, either express or implied.
  *
  ***************************************************************************/
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef USE_NSS
 /*
index c67342a..252bf11 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef NETWARE /* Novell NetWare */
 
index dd32911..23ff2a7 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef NETWARE /* Novell NetWare */
 
index 9ccfa7f..4c395fa 100644 (file)
@@ -21,7 +21,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #if !defined(CURL_DISABLE_LDAP) && defined(USE_OPENLDAP)
 
index b6079bc..1ddd008 100644 (file)
@@ -73,7 +73,7 @@
 
 */
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef HAVE_LIMITS_H
 #include <limits.h>
index 85a7a45..16b4ad3 100644 (file)
@@ -23,7 +23,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #include "urldata.h"
 #include "sendf.h"
index 1d104cf..b48c1ed 100644 (file)
@@ -22,7 +22,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #if !defined(CURL_DISABLE_IMAP) || !defined(CURL_DISABLE_FTP) || \
   !defined(CURL_DISABLE_POP3) || !defined(CURL_DISABLE_SMTP)
index ef074be..f4ca63e 100644 (file)
@@ -27,7 +27,7 @@
  *
  */
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef USE_POLARSSL
 
index ad65546..12b3db2 100644 (file)
@@ -21,7 +21,7 @@
  * KIND, either express or implied.
  *
  ***************************************************************************/
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef USE_POLARSSL
 
index dcb2e69..e8fd9c5 100644 (file)
@@ -30,7 +30,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifndef CURL_DISABLE_POP3
 
index e73f018..4cff2b7 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #include "urldata.h"
 #include "sendf.h"
index 172df31..8ef6fec 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef USE_QSOSSL
 
index a523cb1..1fb47b8 100644 (file)
@@ -21,7 +21,7 @@
  * KIND, either express or implied.
  *
  ***************************************************************************/
-#include "setup.h"
+#include "curl_setup.h"
 
 /*
  * This header should only be needed to get included by sslgen.c and qssl.c
index 2cf2fe7..e27dac4 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #include "rawstr.h"
 
index ca9788e..9d7a9a9 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifndef CURL_DISABLE_RTSP
 
index b70310b..3c46953 100644 (file)
@@ -41,7 +41,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.  */
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifndef CURL_DISABLE_FTP
 #if defined(HAVE_KRB4) || defined(HAVE_GSSAPI)
index 32b6fa5..d13e122 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef HAVE_SYS_SELECT_H
 #include <sys/select.h>
index d66873f..00789bb 100644 (file)
@@ -22,7 +22,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef HAVE_SYS_POLL_H
 #include <sys/poll.h>
index b45e43a..c64d686 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #include <curl/curl.h>
 
index 39911d0..39489e4 100644 (file)
@@ -22,7 +22,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 CURLcode Curl_sendf(curl_socket_t sockfd, struct connectdata *,
                     const char *fmt, ...);
index 477c35b..b21c9f6 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #include <curl/curl.h>
 #include "urldata.h"
index b9e6c25..9a5128e 100644 (file)
@@ -22,7 +22,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 #include <curl/curl.h>
 #include "cookie.h"
 #include "urldata.h"
index 4ddebb6..92c699e 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #include "curl_memory.h"
 #include "slist.h"
index 9a759ab..2ad2ac6 100644 (file)
@@ -28,7 +28,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifndef CURL_DISABLE_SMTP
 
index 522a219..6a2151c 100644 (file)
@@ -22,7 +22,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 struct Curl_sockaddr_storage {
   union {
index 13a756a..51bb946 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #if !defined(CURL_DISABLE_PROXY)
 
index 0ce0bd0..dc4670b 100644 (file)
@@ -22,7 +22,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef CURL_DISABLE_PROXY
 #define Curl_SOCKS4(a,b,c,d,e,f) CURLE_NOT_BUILT_IN
index 02dd485..1f840bd 100644 (file)
@@ -21,7 +21,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifndef CURL_DISABLE_PROXY
 
index 6e95e3c..b4b23e0 100644 (file)
@@ -21,7 +21,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #if defined(USE_WINDOWS_SSPI) && !defined(CURL_DISABLE_PROXY)
 
index ca2323f..ea17a59 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #include <curl/curl.h>
 #include "urldata.h"
index fc40e7d..786cd12 100644 (file)
@@ -22,7 +22,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #include "timeval.h"
 
index b6664e6..3570712 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #include "splay.h"
 
index 49a6dec..5f9ef24 100644 (file)
@@ -21,7 +21,7 @@
  * KIND, either express or implied.
  *
  ***************************************************************************/
-#include "setup.h"
+#include "curl_setup.h"
 
 struct Curl_tree {
   struct Curl_tree *smaller; /* smaller node */
index 1cc4bcd..8eb2e9f 100644 (file)
--- a/lib/ssh.c
+++ b/lib/ssh.c
@@ -22,7 +22,7 @@
 
 /* #define CURL_LIBSSH2_DEBUG */
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef USE_LIBSSH2
 
index bf43fdf..ff2e16b 100644 (file)
--- a/lib/ssh.h
+++ b/lib/ssh.h
@@ -22,7 +22,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef HAVE_LIBSSH2_H
 #include <libssh2.h>
index 67dd71f..4875874 100644 (file)
@@ -43,7 +43,7 @@
    http://httpd.apache.org/docs-2.0/ssl/ssl_intro.html
 */
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #include "urldata.h"
 #define SSLGEN_C
index 2369b55..17ad8e3 100644 (file)
@@ -21,7 +21,7 @@
  * KIND, either express or implied.
  *
  ***************************************************************************/
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifndef MD5_DIGEST_LENGTH
 #define MD5_DIGEST_LENGTH 16 /* fixed size */
index 8f9fce4..c4c465c 100644 (file)
@@ -30,7 +30,7 @@
  * Sampo Kellomaki 1998.
  */
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef HAVE_LIMITS_H
 #include <limits.h>
index 5375a6a..bdec2b5 100644 (file)
@@ -22,7 +22,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef USE_SSLEAY
 /*
index 2701435..3b776b1 100644 (file)
@@ -22,7 +22,7 @@
 /*
  * This file is 'mem-include-scan' clean. See test 1132.
  */
-#include "setup.h"
+#include "curl_setup.h"
 
 #include "strdup.h"
 
index 4edbcd7..49af911 100644 (file)
@@ -21,7 +21,7 @@
  * KIND, either express or implied.
  *
  ***************************************************************************/
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifndef HAVE_STRDUP
 extern char *curlx_strdup(const char *str);
index 89ad8a6..f69c5bf 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef HAVE_STRINGS_H
 #include <strings.h>
index 0c82a53..58c6dc3 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef HAVE_STRERROR_R
 #  if (!defined(HAVE_POSIX_STRERROR_R) && \
index 94eac0e..0d31351 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifndef HAVE_STRTOK_R
 #include <stddef.h>
index 8baf779..1147d70 100644 (file)
@@ -21,7 +21,7 @@
  * KIND, either express or implied.
  *
  ***************************************************************************/
-#include "setup.h"
+#include "curl_setup.h"
 #include <stddef.h>
 
 #ifndef HAVE_STRTOK_R
index c61459d..03a97e8 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #include "strtoofft.h"
 
index 08b0e6d..b812a67 100644 (file)
@@ -22,7 +22,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 /*
  * Determine which string to integral data type conversion function we use
index a64da09..77d8b7b 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifndef CURL_DISABLE_TELNET
 
index 97276ea..282460b 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifndef CURL_DISABLE_TFTP
 
index b464ae4..3f1b9ea 100644 (file)
@@ -27,7 +27,7 @@
  * as well as the library. Do not mix with library internals!
  */
 
-#include "setup.h"
+#include "curl_setup.h"
 
 struct timeval curlx_tvnow(void);
 
index 6194908..6be43ea 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #include "strtoofft.h"
 #include "strequal.h"
index 58befec..c107d2c 100644 (file)
--- a/lib/url.c
+++ b/lib/url.c
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #ifdef HAVE_NETINET_IN_H
 #include <netinet/in.h>
index ab6d3d0..a026e90 100644 (file)
--- a/lib/url.h
+++ b/lib/url.h
@@ -21,7 +21,7 @@
  * KIND, either express or implied.
  *
  ***************************************************************************/
-#include "setup.h"
+#include "curl_setup.h"
 
 /*
  * Prototypes for library-wide functions provided by url.c
index cd50f62..576872d 100644 (file)
@@ -24,7 +24,7 @@
 
 /* This file is for lib internal stuff */
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #define PORT_FTP 21
 #define PORT_FTPS 990
index ef8353a..d39fe0c 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #include <curl/curl.h>
 #include "urldata.h"
index 9cc7be9..b1eaa96 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #if defined(__INTEL_COMPILER) && defined(__unix__)
 
index 6f4c738..7130d5e 100644 (file)
@@ -20,7 +20,7 @@
  *
  ***************************************************************************/
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #include "wildcard.h"
 #include "llist.h"
index 2e2d868..842cc40 100644 (file)
@@ -21,7 +21,7 @@
 #***************************************************************************
 
 # File version for 'aclocal' use. Keep it a single number.
-# serial 8
+# serial 10
 
 dnl Note 1
 dnl ------
@@ -467,7 +467,7 @@ dnl This macro ensures that configuration tests done
 dnl after this will execute with preprocessor symbol
 dnl _REENTRANT defined. This macro also ensures that
 dnl the generated config file defines NEED_REENTRANT
-dnl and that in turn setup.h will define _REENTRANT.
+dnl and that in turn curl_setup.h will define _REENTRANT.
 dnl Internal macro for CURL_CONFIGURE_REENTRANT.
 
 AC_DEFUN([CURL_CONFIGURE_FROM_NOW_ON_WITH_REENTRANT], [
@@ -487,7 +487,7 @@ dnl This macro ensures that configuration tests done
 dnl after this will execute with preprocessor symbol
 dnl _THREAD_SAFE defined. This macro also ensures that
 dnl the generated config file defines NEED_THREAD_SAFE
-dnl and that in turn setup.h will define _THREAD_SAFE.
+dnl and that in turn curl_setup.h will define _THREAD_SAFE.
 dnl Internal macro for CURL_CONFIGURE_THREAD_SAFE.
 
 AC_DEFUN([CURL_CONFIGURE_FROM_NOW_ON_WITH_THREAD_SAFE], [
index 5527ce7..1dd3a79 100644 (file)
@@ -24,7 +24,7 @@
 /* OS/400 additional support. */
 
 #include "curlbuild.h"
-#include "config-os400.h"       /* Not setup.h: we only need some defines. */
+#include "config-os400.h"  /* Not curl_setup.h: we only need some defines. */
 
 #include <sys/types.h>
 #include <sys/socket.h>
index 93f86cb..bda8357 100644 (file)
@@ -25,8 +25,8 @@ source_group("cURL source files" FILES ${CURL_CFILES})
 source_group("cURL header files" FILES ${CURL_HFILES})
 
 include_directories(
-  ${CURL_SOURCE_DIR}/lib                # To be able to reach "setup_once.h"
-  ${CURL_BINARY_DIR}/lib                # To be able to reach "curl_config.h"
+  ${CURL_SOURCE_DIR}/lib        # To be able to reach "curl_setup_once.h"
+  ${CURL_BINARY_DIR}/lib        # To be able to reach "curl_config.h"
   ${CURL_BINARY_DIR}/include    # To be able to reach "curl/curlbuild.h"
   )
 
index 54162b3..7e98d11 100644 (file)
@@ -27,11 +27,11 @@ AUTOMAKE_OPTIONS = foreign nostdinc
 # might possibly already be installed in the system.
 #
 # $(top_builddir)/include/curl for generated curlbuild.h included from curl.h
-# $(top_builddir)/include for generated curlbuild.h included from lib/setup.h
+# $(top_builddir)/include for generated curlbuild.h inc. from lib/curl_setup.h
 # $(top_srcdir)/include is for libcurl's external include files
 # $(top_builddir)/lib is for libcurl's generated lib/curl_config.h file
 # $(top_builddir)/src is for curl's generated src/curl_config.h file
# $(top_srcdir)/lib is for libcurl's lib/setup.h and other "borrowed" files
 # $(top_srcdir)/src is for curl's src/tool_setup.h and "curl-private" files
 
 AM_CPPFLAGS = -I$(top_builddir)/include/curl \
index ed3849b..9ed7260 100644 (file)
@@ -33,7 +33,7 @@
  * therefore we must include setup.h before curl.h when building curl.
  */
 
-#include "setup.h" /* from the lib directory */
+#include "curl_setup.h" /* from the lib directory */
 
 /*
  * curl tool certainly uses libcurl's external interface.
index 896686b..733cdd3 100644 (file)
@@ -5,7 +5,7 @@ function(SETUP_TEST TEST_NAME)          # ARGN are the files in the test
   string(TOUPPER ${TEST_NAME} UPPER_TEST_NAME)
 
   include_directories(
-    ${CURL_SOURCE_DIR}/lib          # To be able to reach "setup_once.h"
+    ${CURL_SOURCE_DIR}/lib          # To be able to reach "curl_setup_once.h"
     ${CURL_BINARY_DIR}/lib          # To be able to reach "curl_config.h"
     ${CURL_BINARY_DIR}/include      # To be able to reach "curl/curlbuild.h"
     )
index df13df1..ba4097f 100644 (file)
@@ -27,10 +27,10 @@ AUTOMAKE_OPTIONS = foreign nostdinc
 # might possibly already be installed in the system.
 #
 # $(top_builddir)/include/curl for generated curlbuild.h included from curl.h
-# $(top_builddir)/include for generated curlbuild.h included from lib/setup.h
+# $(top_builddir)/include for generated curlbuild.h inc. from lib/curl_setup.h
 # $(top_srcdir)/include is for libcurl's external include files
 # $(top_builddir)/lib is for libcurl's generated lib/curl_config.h file
# $(top_srcdir)/lib is for libcurl's lib/setup.h and other "borrowed" files
 # $(top_builddir)/ares is for in-tree c-ares's generated ares_build.h file
 # $(top_srcdir)/ares is for in-tree c-ares's external include files
 
index a18c92e..168294a 100644 (file)
@@ -19,7 +19,7 @@
  * KIND, either express or implied.
  *
  ***************************************************************************/
-#include "setup.h"
+#include "curl_setup.h"
 
 #include "curl_gethostname.h"
 
index f131fe9..9da6a67 100644 (file)
@@ -19,7 +19,7 @@
  * KIND, either express or implied.
  *
  ***************************************************************************/
-#include "setup.h"
+#include "curl_setup.h"
 
 #include "sethostname.h"
 
index fcc91ad..5de8c7c 100644 (file)
  *
  ***************************************************************************/
 
/* Now include the setup.h file from libcurl's private libdir (the source
    version, but that might include "curl_config.h" from the build dir so we
    need both of them in the include path), so that we get good in-depth
    knowledge about the system we're building this on */
 
 #define CURL_NO_OLDIES
 
-#include "setup.h"
+#include "curl_setup.h"
 
 #include <curl/curl.h>
 
index 3ad18c9..b18a607 100644 (file)
@@ -19,7 +19,7 @@
  * KIND, either express or implied.
  *
  ***************************************************************************/
-#include "setup.h"
+#include "curl_setup.h"
 
 #include "testutil.h"
 #include "memdebug.h"
index 0c6be2f..a236970 100644 (file)
@@ -21,7 +21,7 @@
  * KIND, either express or implied.
  *
  ***************************************************************************/
-#include "setup.h"
+#include "curl_setup.h"
 
 struct timeval tutil_tvnow(void);
 
index 0401df2..69cc56c 100644 (file)
@@ -5,8 +5,8 @@ function(SETUP_EXECUTABLE TEST_NAME)    # ARGN are the files in the test
   string(TOUPPER ${TEST_NAME} UPPER_TEST_NAME)
 
   include_directories(
-    ${CURL_SOURCE_DIR}/lib              # To be able to reach "setup_once.h"
-    ${CURL_BINARY_DIR}/lib              # To be able to reach "curl_config.h"
+    ${CURL_SOURCE_DIR}/lib      # To be able to reach "curl_setup_once.h"
+    ${CURL_BINARY_DIR}/lib      # To be able to reach "curl_config.h"
     ${CURL_BINARY_DIR}/include  # To be able to reach "curl/curlbuild.h"
     )
   if(CURL_USE_ARES)
index d4ef252..7533a98 100644 (file)
@@ -27,10 +27,10 @@ AUTOMAKE_OPTIONS = foreign nostdinc
 # might possibly already be installed in the system.
 #
 # $(top_builddir)/include/curl for generated curlbuild.h included from curl.h
-# $(top_builddir)/include for generated curlbuild.h included from lib/setup.h
+# $(top_builddir)/include for generated curlbuild.h inc. from lib/curl_setup.h
 # $(top_srcdir)/include is for libcurl's external include files
 # $(top_builddir)/lib is for libcurl's generated lib/curl_config.h file
# $(top_srcdir)/lib is for libcurl's lib/setup.h and other "borrowed" files
 # $(top_builddir)/ares is for in-tree c-ares's generated ares_build.h file
 # $(top_srcdir)/ares is for in-tree c-ares's external include files
 
index 193ad84..59e3695 100644 (file)
@@ -24,6 +24,6 @@
 
 #define CURL_NO_OLDIES
 
-#include "setup.h" /* portability help from the lib directory */
+#include "curl_setup.h" /* portability help from the lib directory */
 
 #endif /* HEADER_CURL_SERVER_SETUP_H */
index eb29241..12d5fe3 100644 (file)
@@ -27,10 +27,10 @@ AUTOMAKE_OPTIONS = foreign nostdinc
 # might possibly already be installed in the system.
 #
 # $(top_builddir)/include/curl for generated curlbuild.h included from curl.h
-# $(top_builddir)/include for generated curlbuild.h included from lib/setup.h
+# $(top_builddir)/include for generated curlbuild.h inc. from lib/curl_setup.h
 # $(top_srcdir)/include is for libcurl's external include files
 # $(top_builddir)/lib is for libcurl's generated lib/curl_config.h file
# $(top_srcdir)/lib is for libcurl's lib/setup.h and other "borrowed" files
 # $(top_builddir)/ares is for in-tree c-ares's generated ares_build.h file
 # $(top_srcdir)/ares is for in-tree c-ares's external include files
@@ -27,11 +27,11 @@ AUTOMAKE_OPTIONS = foreign nostdinc
 # $(top_builddir)/lib is for libcurl's generated lib/curl_config.h file
 # $(top_builddir)/src is for curl's generated src/curl_config.h file
-# $(top_srcdir)/lib is for libcurl's lib/setup.h and other "borrowed" files
+# $(top_srcdir)/lib for libcurl's lib/curl_setup.h and other "borrowed" files
 # $(top_srcdir)/src is for curl's src/tool_setup.h and "curl-private" files
 
@@ -27,10 +27,10 @@ AUTOMAKE_OPTIONS = foreign nostdinc
 # $(top_srcdir)/include is for libcurl's external include files
 # $(top_builddir)/lib is for libcurl's generated lib/curl_config.h file
-# $(top_srcdir)/lib is for libcurl's lib/setup.h and other "borrowed" files
+# $(top_srcdir)/lib for libcurl's lib/curl_setup.h and other "borrowed" files
 # $(top_builddir)/ares is for in-tree c-ares's generated ares_build.h file
 # $(top_srcdir)/ares is for in-tree c-ares's external include files
@@ -19,7 +19,7 @@
  ***************************************************************************/
 
-/* Now include the setup.h file from libcurl's private libdir (the source
+/* Now include the curl_setup.h file from libcurl's private libdir (the source
    version, but that might include "curl_config.h" from the build dir so we
    need both of them in the include path), so that we get good in-depth
@@ -27,10 +27,10 @@ AUTOMAKE_OPTIONS = foreign nostdinc
 # $(top_srcdir)/include is for libcurl's external include files
 # $(top_builddir)/lib is for libcurl's generated lib/curl_config.h file
-# $(top_srcdir)/lib is for libcurl's lib/setup.h and other "borrowed" files
+# $(top_srcdir)/lib for libcurl's lib/curl_setup.h and other "borrowed" files
 # $(top_builddir)/ares is for in-tree c-ares's generated ares_build.h file
 # $(top_srcdir)/ares is for in-tree c-ares's external include files
@@ -27,10 +27,10 @@ AUTOMAKE_OPTIONS = foreign nostdinc
 # $(top_srcdir)/include is for libcurl's external include files
 # $(top_builddir)/lib is for libcurl's generated lib/curl_config.h file
-# $(top_srcdir)/lib is for libcurl's lib/setup.h and other "borrowed" files
+# $(top_srcdir)/lib for libcurl's lib/curl_setup.h and other "borrowed" files
 # $(top_builddir)/ares is for in-tree c-ares's generated ares_build.h file
 # $(top_srcdir)/ares is for in-tree c-ares's external include files